ComputeFseg: Computes inbreeding coefficients based on HBD segments...

ComputeFsegR Documentation

Computes inbreeding coefficients based on HBD segments identified with the Viterbi algorithm (similar to a F_ROH estimator), restricted to HBD classes with a rate lower or equal to a chosen threshold T. Returns, per individual, the number of qualifying segments and the corresponding inbreeding coefficient FSEG.

Description

Computes inbreeding coefficients based on HBD segments identified with the Viterbi algorithm (similar to a F_ROH estimator), restricted to HBD classes with a rate lower or equal to a chosen threshold T. Returns, per individual, the number of qualifying segments and the corresponding inbreeding coefficient FSEG.

Usage

ComputeFseg(zoores, zoodata, T = NULL, use_names = FALSE)

Arguments

zoores

a zoores object (output of zoorun)

zoodata

a zooin object (output of zoodata), it must be the zooin object associated to the zoores object

T

is the maximum HBD class rate to include (classes with zoores@krates <= T are summed)

use_names

if TRUE, replaces numeric identifiers with the individual names (zoodata@sample_ids). In that case, zoodata@sample_ids must exist. Set to FALSE (default) for an IBD analysis (in that case ids do not correspond to sample_ids but to positions in the list of pairs).

Value

a data.frame with one row per individual, the number of HBD segments (NSEG) and the inbreeding coefficient (FSEG) computed over all classes with rate <= T.


RZooRoH documentation built on Oct. 3, 2026, 1:06 a.m.