merge_kinres: Merge several kinres objects generated by zookin

View source: R/zookin_accessor.R

merge_kinresR Documentation

Merge several kinres objects generated by zookin

Description

The function is used for example when the kinship analysis has been split in several tasks. All the kinres objects must come from the same original zoodata and from zookin() runs using the same model (zookin is applied to the same zoodata with the same model - as for merge_zres). In addition, the data should not overlap (the same pair of individuals should not be present in multiple kinres objects).

Usage

merge_kinres(list_kinres)

Arguments

list_kinres

A list with the name of the kinres objects to be merged.

Value

a single kinres object containing the results from the merged kinres objects. Note that the IBD segments are not sorted by ID number.


RZooRoH documentation built on Oct. 3, 2026, 1:06 a.m.