update_kinres: Update one main kinres object with new results

View source: R/zookin_accessor.R

update_kinresR Documentation

Update one main kinres object with new results

Description

The function is used for example when the main kinship analysis failed for one pair of individuals. The analysis is repeated for that pair with other settings, and the function inserts the new results in the main kinres object. The pair(s) in kinres2 must already be present in kinres1, and both objects must come from the same zoodata and the same model (as for update_zres). To avoid generating too large files, the updated kinres object can take the same name as kinres1, doing kinres1 <- update_kinres(kinres1,kinres2).

Usage

update_kinres(kinres1, kinres2)

Arguments

kinres1

The main kinres object that will be modified.

kinres2

The new kinres object, with the new results that will be inserted in the main kinres object.

Value

an updated kinres object containing the results from kinres1 updated by those from kinres2.


RZooRoH documentation built on Oct. 3, 2026, 1:06 a.m.