| ComputeFseg | R Documentation |
Computes inbreeding coefficients based on HBD segments identified with the Viterbi algorithm (similar to a F_ROH estimator), restricted to HBD classes with a rate lower or equal to a chosen threshold T. Returns, per individual, the number of qualifying segments and the corresponding inbreeding coefficient FSEG.
ComputeFseg(zoores, zoodata, T = NULL, use_names = FALSE)
zoores |
a zoores object (output of zoorun) |
zoodata |
a zooin object (output of zoodata), it must be the zooin object associated to the zoores object |
T |
is the maximum HBD class rate to include (classes with zoores@krates <= T are summed) |
use_names |
if TRUE, replaces numeric identifiers with the individual names (zoodata@sample_ids). In that case, zoodata@sample_ids must exist. Set to FALSE (default) for an IBD analysis (in that case ids do not correspond to sample_ids but to positions in the list of pairs). |
a data.frame with one row per individual, the number of HBD segments (NSEG) and the inbreeding coefficient (FSEG) computed over all classes with rate <= T.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.