View source: R/zooroh_accessor.R
| ComputeFsegAllT | R Documentation |
Computes inbreeding coefficients based on HBD segments identified with the Viterbi algorithm (similar to a F_ROH estimator). Returns cumulative inbreeding coefficients estimated using different thresholds corresponding to the rates of the HBD classes.
ComputeFsegAllT(zoores, zoodata, use_names = FALSE)
zoores |
a zoores object (output of zoorun) |
zoodata |
a zooin object (output of zoodata), it must be the zooin object associated to the zoores object |
use_names |
if TRUE, replaces numeric identifiers with the individual names (zoodata@sample_ids). In that case, zoodata@sample_ids must exit. Set to FALSE (default) for an IBD analysis (in that case ids do not correspond to sample_ids but to positions in the list of pairs). |
a data.frame with one row per individual and one column per HBD class (cumulative), column names being prefixed "F_class". The values are the inbreeding coefficient estimated using HBD segments associated with HBD classes with a rate lower or equal to the threshold.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.