View source: R/zooroh_accessor.R
| update_zres | R Documentation |
The function is used for example when the main analysis failed for one individual (or one pair, in an IBD analysis). The analysis is repeated with other settings and the function inserts the new results in the main zres object. However the model must still be the same! The individual(s)/pair(s) in zres2 must already be present in zres1. To avoid generating too large files, the updated zres object can take the same name as zres1, doing zres1 <- update_zres(zres1,zres2).
update_zres(zres1, zres2)
zres1 |
The main zres object that will be modified. |
zres2 |
The new zres object, with the new results that will be inserted in the main zres object. |
As for merge_zres, the function detects automatically whether this is a standard (HBD) or an IBD analysis from the format of @sampleids, and matches accordingly (on @ids for a standard analysis, on @sampleids for an IBD analysis, since @ids are then only local to each zoorun() call). In both cases, @ids in zres1 are left unchanged.
an updated zres object containing the results from zres1 updated by those from zres2.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.